CpalOutputConfig

Struct CpalOutputConfig 

pub struct CpalOutputConfig {
    pub host: Option<HostId>,
    pub device_id: Option<DeviceId>,
    pub desired_sample_rate: Option<u32>,
    pub desired_block_frames: Option<u32>,
    pub fallback: bool,
}
The configuration of an output audio stream in the CPAL backend.

Fields

host: Option<HostId>

The host to use. Set to None to use the system’s default audio host.

device_id: Option<DeviceId>

The id of the output device to use. Set to None to use the system’s default output device.

By default this is set to None.

desired_sample_rate: Option<u32>

The desired sample rate to use. Set to None to use the device’s default sample rate.

By default this is set to None.

desired_block_frames: Option<u32>

The latency/block size of the audio stream to use. Set to None to use the device’s default value.

Smaller values may give better latency, but is not supported on all platforms and may lead to performance issues.

This currently has no effect on iOS platforms.

By default this is set to Some(1024).

fallback: bool

Whether or not to fall back to the default device if a device with the given configuration could not be found.

By default this is set to true.